@@ -410,13 +410,35 @@ class CraigslistBase(object):
             cls.__list_filters[url] = utils.get_list_filters(url)
         return cls.__list_filters[url]
 
+    @classmethod
+    def show_categories(cls):
+        url = cls.url_templates["no_area"] % {
+            "site": cls.default_site,
+            "category": cls.default_category,
+        }
+        response = utils.requests_get(url)
+        soup = utils.bs(response.content)
+
+        cat_html = soup.find_all("input", {"class": "catcheck multi_checkbox"})
+        cat_ids = [html.get('data-abb') for html in cat_html]
+        cat_html = soup.find_all("a", {"class": "category"})
+        cat_names = [html.contents[0] for html in cat_html]
+
+        print("%s categories:" % cls.__name__)
+        for cat_name, cat_id in sorted(zip(cat_names, cat_ids)):
+            print("* %s = %s" % (cat_id, cat_name))
+
     @classmethod
     def show_filters(cls, category=None):
         print('Base filters:')
         for key, options in iteritems(cls.base_filters):
             value_as_str = '...' if options['value'] is None else 'True/False'
             print('* %s = %s' % (key, value_as_str))
-        print('Section specific filters:')
+
+        if category is None:
+            print("\n%s filters:" % cls.__name__)
+        else:
+            print("\n%s filters for category '%s':" % (cls.__name__, category))
         for key, options in iteritems(cls.extra_filters):
             value_as_str = '...' if options['value'] is None else 'True/False'
             print('* %s = %s' % (key, value_as_str))
